### Katharà

Thank you for installing Katharà __VERSION__!

#### Run Katharà

Open a new Terminal and run the following command to get started with Katharà:

`$ kathara [command]`

#### Kathara

Go through the following links for additional information:

- Katharà Official Site
- Katharà Wiki

#### Uninstall Katharà

Run the following command to uninstall Katharà:

`$ sudo bash /Library/Kathara/uninstall.sh`